@@ -1,11 +1,11 @@
 package Test::Mock::Time;
-use 5.018000;
+use 5.010001;
 use warnings;
 use strict;
 use utf8;
 use Carp;
 
-our $VERSION = 'v0.1.0';
+our $VERSION = 'v0.1.1';
 
 use Export::Attrs;
 use Scalar::Util qw( weaken );
@@ -128,11 +128,11 @@ sub _mock_core_global {
         return int($Absolute + $Relative);
     });
     $Module{'CORE::GLOBAL'}->mock(localtime => sub (;$) {
-        my $time = $_[0] // CORE::GLOBAL::time();
+        my $time = $_[0] // int($Absolute + $Relative);
         return CORE::localtime($time);
     });
     $Module{'CORE::GLOBAL'}->mock(gmtime => sub (;$) {
-        my $time = $_[0] // CORE::GLOBAL::time();
+        my $time = $_[0] // int($Absolute + $Relative);
         return CORE::gmtime($time);
     });
     $Module{'CORE::GLOBAL'}->mock(sleep => sub ($) {
@@ -458,8 +458,7 @@ Test::Mock::Time - Deterministic time & timers for event loop tests
 
 =head1 VERSION
 
-This document describes Test::Mock::Time version v0.1.0
-
+This document describes Test::Mock::Time version v0.1.1
 =head1 SYNOPSIS
 
   use Test::Mock::Time;
